

recipe_file <- "modules/data_load/testing_recipes/recipe_4.yml"

source("modules/data_load/load.R")

data <- load_datasets(recipe_file)

## Entry params data and recipe?
## TODO: Instead of reading the recipe at each module, do it at the beginning?
recipe <- read_yaml(recipe_file)

calibrate_datasets <- function(data, recipe) {
  # hcst <- data$hcst
  # obs <- data$obs
  # fcst <- data$fcst
  
  # Calibration function params
  method <- recipe$Analysis$Workflow$Calibration$method
  ## TODO: Make sure 'Multimodel' param in recipe is a boolean
  mm <- recipe$Analysis$Datasets$Multimodel
  ncores <- 4
  na.rm <- T
  
  # Hcst calibration 
  hcst_calib <- CSTools::CST_Calibration(data$hcst, data$obs,
                                         cal.method = method,
                                         eval.method = "leave-one-out",
                                         multi.model = mm,
                                         na.fill = TRUE,
                                         na.rm = na.rm,
                                         apply_to = NULL,
                                         alpha = NULL,
                                         memb_dim = "ensemble",
                                         sdate_dim = "syear",
                                         ncores = ncores)
  
  ## Alba's version
  library(s2dv)
  library(ClimProjDiags)
  library(multiApply)
  source("https://earth.bsc.es/gitlab/external/cstools/-/raw/develop-CalibrationForecast/R/CST_Calibration.R")
  hcst_calibrated <- CST_Calibration(data$hcst, data$obs,
                                     cal.method = method,
                                     eval.method = "leave-one-out",
                                     multi.model = mm,
                                     na.fill = TRUE,
                                     na.rm = na.rm,
                                     apply_to = NULL,
                                     alpha = NULL,
                                     memb_dim = "ensemble",
                                     sdate_dim = "syear",
                                     ncores = ncores)
  
  ## In the new CST_Calibration function, the fcst must have the same number of 
  ## dimensions as the hcst
  dim(data$fcst$data) <- c(dim(data$fcst$data)[1:2], "sday" = 1, "sweek" = 1,
  			 dim(data$fcst$data)[3:7])
  ## In the new CST_Calibration function, memb_dim and sdate_dim must be the same
  ## in the hcst and the fcst.
  names(dim(data$fcst$data))[which(names(dim(data$fcst$data)) == 
  				 'fcst_syear')] <- "syear"
  
  fcst_alba <- CST_Calibration(data$hcst, data$obs, data$fcst,
                              cal.method = method,
                              eval.method = "leave-one-out",
                              multi.model = mm,
                              na.fill = TRUE,
                              na.rm = na.rm,
                              apply_to = NULL,
                              alpha = NULL,
                              memb_dim = "ensemble",
                              sdate_dim = "syear",
                              ncores = ncores)
  
  ## Lluís' version:
  ## Note: memb_dim is hardcoded as 'ensemble'.
  source("/esarchive/scratch/vagudets/repos/auto-s2s/modules/Calibration/Calibration.R")
  hcst_lluis <- hcst_calib(data$obs, data$hcst,
  			   method = method,
  			   mm = mm,
  			   na.rm = na.rm,
  			   split_factor = 1,
  			   ncores = ncores)
  ## TODO: Include Lluís' forecast version and test it
  # For daily
  # hcst <- CSTools::CST_QuantileMapping(data$hcst,
  #                                      data$obs,
  #                                      exp_cor = NULL,
  #                                      sample_dims = c("syear", "time", "ensemble"),
  #                                      sample_length = NULL,
  #                                      method = "QUANT",
  #                                      ncores = ncores,
  #                                      na.rm = na.rm)
